#! /usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const optimist_1 = require("optimist");
const dir_to_iis_app_service_1 = require("./dir-to-iis-app-service");
setupCli();
const service = new dir_to_iis_app_service_1.DirToIisAppService(processAliases());
if (optimist_1.argv.h || optimist_1.argv.help) {
    help();
}
else if (optimist_1.argv.uninstall) {
    service.uninstall();
}
else {
    service.install();
}
function setupCli() {
    optimist_1.usage(`Usage: dir-to-iis-app\n       dir-to-iis-app --uninstall`);
    optimist_1.options('name', {
        alias: 'n',
        describe: `Windows service name to install/uninstall (don't confuse with the display name.`,
        type: 'string'
    });
    optimist_1.options('site', {
        alias: ['s', 'website', 'w'],
        describe: `IIS website name. Name should match to the website at IIS.`,
        type: 'string'
    });
    optimist_1.options('paths', {
        alias: ['p', 'path'],
        describe: `Paths to files, dirs to be watched recursively, or glob patterns.`,
        type: 'string'
    });
    optimist_1.options('interval', {
        alias: 'i',
        describe: `Interval of file system polling, in milliseconds.`,
        type: 'string'
    });
    optimist_1.options('depth', {
        alias: 'd',
        describe: `Limits how many levels of subdirectories will be traversed? (Leave -1 to unlimited)`,
        type: 'string'
    });
    optimist_1.options('startImmediately', {
        alias: ['r', 'immediately', 'start'],
        describe: `Should the service get started immediately.`,
        type: 'boolean'
    });
}
function help() {
    optimist_1.showHelp();
}
function processAliases() {
    const opts = optimist_1.argv;
    if (!opts.name) {
        opts.name = opts.n;
        delete opts.n;
    }
    if (!opts.site) {
        opts.site = opts.website || opts.s || opts.w;
        delete opts.website;
        delete opts.s;
        delete opts.w;
    }
    if (!opts.paths) {
        opts.paths = opts.path || opts.p;
        delete opts.path;
        delete opts.p;
    }
    if (!opts.interval) {
        opts.interval = opts.i;
        delete opts.i;
    }
    if (!opts.depth) {
        opts.depth = opts.d;
        delete opts.d;
    }
    if (!opts.startImmediately) {
        opts.startImmediately = opts.immediately || opts.start || opts.r;
        delete opts.immediately;
        delete opts.start;
        delete opts.r;
    }
    return opts;
}
//# sourceMappingURL=index.js.map