"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chokidar_1 = require("chokidar");
const path_1 = require("path");
const node_windows_1 = require("node-windows");
require("colors");
const app_host_config_1 = require("./app-host-config");
class Watcher {
    constructor(options) {
        this.options = options;
        this._logger = new node_windows_1.EventLogger({ source: 'watcher' });
        this._logger.info(`Watcher options ${JSON.stringify(this.options)}`);
        this.config = new app_host_config_1.AppHostConfig();
        this.siteApplication = this.config.getSiteApplication(this.options.site);
    }
    run() {
        const path = path_1.resolve(this.siteApplication.physicalPath, this.options.paths);
        if (!path) {
            const error = `There is something weird with ${this.options.site} config.`;
            this._logger.error(error);
            throw new ReferenceError(error);
        }
        this._logger.info(`Starting watching on ${path} (${this.options.site})`);
        const interval = Number(this.options.interval);
        const watchOptions = {
            ignoreInitial: true,
            cwd: path_1.resolve(this.siteApplication.physicalPath),
            usePolling: true,
            interval,
            depth: Number(this.options.depth) > -1 ? Number(this.options.depth) : undefined,
            awaitWriteFinish: {
                stabilityThreshold: interval,
                pollInterval: interval
            }
        };
        const srcPath = this.options.paths;
        chokidar_1.watch(srcPath, watchOptions).on('add', async (filePath) => await this.$add(filePath));
        chokidar_1.watch(srcPath, watchOptions).on('unlink', async (filePath) => await this.$remove(filePath));
    }
    async $add(filePath) {
        const physicalPath = path_1.join(this.siteApplication.physicalPath, path_1.parse(filePath).dir);
        const path = this._toApplicationPath(physicalPath);
        await this.config.addSiteApplication(this.options.site, {
            path,
            pool: this.siteApplication.pool,
            physicalPath
        });
    }
    async $remove(filePath) {
        const physicalPath = path_1.join(this.siteApplication.physicalPath, path_1.parse(filePath).dir);
        const path = this._toApplicationPath(physicalPath);
        await this.config.removeSiteApplication(this.options.site, path);
    }
    _toApplicationPath(physicalPath) {
        const path = path_1.relative(this.siteApplication.physicalPath, physicalPath)
            .replace(/\\/g, '/');
        return path[0] === '/' ? path : `/${path}`;
    }
}
exports.Watcher = Watcher;
//# sourceMappingURL=watcher.js.map